@@ -28,7 +28,8 @@ def param2grid(params):
     Returns : a parameter grid in the form expected by scikit-learn where each element is a single candidate
     (a single value or a list with one value for each view)
 
-    :Example:
+    Example
+    -------
     >>> params = {'regs': [[1, 2], [3, 4]]}
     >>> param2grid(params)
     {'regs': [[1, 3], [1, 4], [2, 3], [2, 4]]}
@@ -99,11 +100,11 @@ class ParameterSampler_(ParameterSampler):
                 if isinstance(v, Iterable):
                     # if each element is a distribution for each view (i.e. it is a non-string Iterable) then call return_param for each view
                     if any(
-                        [
-                            (isinstance(v_, Iterable) and not isinstance(v_, str))
-                            or hasattr(v_, "rvs")
-                            for v_ in v
-                        ]
+                            [
+                                (isinstance(v_, Iterable) and not isinstance(v_, str))
+                                or hasattr(v_, "rvs")
+                                for v_ in v
+                            ]
                     ):
                         params[k] = [self.return_param(v_) for v_ in v]
                     # if the parameter is shared across views then the list will just contain non-iterable values
@@ -159,18 +160,18 @@ class GridSearchCV(BaseSearchCV):
     _required_parameters = ["estimator", "param_grid"]
 
     def __init__(
-        self,
-        estimator,
-        param_grid,
-        *,
-        scoring=None,
-        n_jobs=None,
-        refit=True,
-        cv=None,
-        verbose=0,
-        pre_dispatch="2*n_jobs",
-        error_score=np.nan,
-        return_train_score=False,
+            self,
+            estimator,
+            param_grid,
+            *,
+            scoring=None,
+            n_jobs=None,
+            refit=True,
+            cv=None,
+            verbose=0,
+            pre_dispatch="2*n_jobs",
+            error_score=np.nan,
+            return_train_score=False,
     ):
         super().__init__(
             estimator=estimator,
@@ -207,7 +208,7 @@ class GridSearchCV(BaseSearchCV):
         self = BaseSearchCV.fit(self, np.hstack(X), y=None, groups=None, **fit_params)
         self.best_estimator_ = self.best_estimator_["estimator"]
         self.best_params_ = {
-            key[len("estimator__") :]: val for key, val in self.best_params_.items()
+            key[len("estimator__"):]: val for key, val in self.best_params_.items()
         }
         return self
 
@@ -246,20 +247,20 @@ class RandomizedSearchCV(BaseSearchCV):
     _required_parameters = ["estimator", "param_distributions"]
 
     def __init__(
-        self,
-        estimator,
-        param_distributions,
-        *,
-        n_iter=10,
-        scoring=None,
-        n_jobs=None,
-        refit=True,
-        cv=None,
-        verbose=0,
-        pre_dispatch="2*n_jobs",
-        random_state=None,
-        error_score=np.nan,
-        return_train_score=False,
+            self,
+            estimator,
+            param_distributions,
+            *,
+            n_iter=10,
+            scoring=None,
+            n_jobs=None,
+            refit=True,
+            cv=None,
+            verbose=0,
+            pre_dispatch="2*n_jobs",
+            random_state=None,
+            error_score=np.nan,
+            return_train_score=False,
     ):
         self.param_distributions = {
             f"estimator__{key}": val for key, val in param_distributions.items()
@@ -296,6 +297,6 @@ class RandomizedSearchCV(BaseSearchCV):
         self = BaseSearchCV.fit(self, np.hstack(X), y=None, groups=None, **fit_params)
         self.best_estimator_ = self.best_estimator_["estimator"]
         self.best_params_ = {
-            key[len("estimator__") :]: val for key, val in self.best_params_.items()
+            key[len("estimator__"):]: val for key, val in self.best_params_.items()
         }
         return self
