@@ -1,4 +1,3 @@
-from cca_zoo.models._multiview import MCCA, KCCA, GCCA, KGCCA, TCCA, KTCCA
 from ._grcca import GRCCA
 from ._iterative import (
     PLS_ALS,
@@ -10,6 +9,7 @@ from ._iterative import (
     SCCA_Span,
     SWCCA,
 )
+from ._multiview import MCCA, KCCA, GCCA, KGCCA, TCCA, KTCCA
 from ._ncca import NCCA
 from ._partialcca import PartialCCA
 from ._prcca import PRCCA
