@@ -5,7 +5,7 @@ from sklearn.utils.fixes import loguniform
 from sklearn.utils.validation import check_random_state
 
 from cca_zoo import cross_validate, permutation_test_score, learning_curve, PRCCA, GRCCA
-from cca_zoo.data import linear_simulated_data
+from cca_zoo.data.simulated import LinearSimulatedData
 from cca_zoo.model_selection import GridSearchCV, RandomizedSearchCV
 from cca_zoo.models import (
     rCCA,
@@ -39,6 +39,11 @@ X_sp = sp.random(n, 10, density=0.5, random_state=rng)
 Y_sp = sp.random(n, 11, density=0.5, random_state=rng)
 
 
+def test_linear_simulated_data():
+    sim_data = LinearSimulatedData([10, 10]).sample(100)
+    assert CCA().fit(sim_data).score(sim_data) > 0.9
+
+
 def test_unregularized_methods():
     # Tests unregularized CCA methods. The idea is that all of these should give the same result.
     latent_dims = 2
@@ -285,7 +290,7 @@ def test_PCCA():
 
     np.random.seed(0)
     # Tests tensor CCA methods
-    (X, Y), (_) = linear_simulated_data(20, [5, 5])
+    X, Y = LinearSimulatedData([5, 5]).sample(100)
     latent_dims = 1
     cca = CCA(latent_dims=latent_dims).fit([X, Y])
     pcca = ProbabilisticCCA(
