@@ -10,7 +10,7 @@ import numpy as np
 import pandas as pd
 from sklearn.utils.fixes import loguniform
 
-from cca_zoo.data import linear_simulated_data
+from cca_zoo.data.simulated import LinearSimulatedData
 from cca_zoo.model_selection import GridSearchCV, RandomizedSearchCV
 from cca_zoo.models import KCCA
 
@@ -25,9 +25,9 @@ q = 100
 latent_dims = 1
 cv = 3
 
-(X, Y), (tx, ty) = linear_simulated_data(
-    n, view_features=[p, q], latent_dims=latent_dims, correlation=[0.9]
-)
+(X, Y), (tx, ty) = LinearSimulatedData(
+    view_features=[p, q], latent_dims=latent_dims, correlation=[0.9]
+).sample(n)
 
 
 # %%
